@@ -7,7 +7,7 @@
 int main() {
 
 	int err;
-    
+
 	CU_pSuite pSuite = NULL;
 
 	/* initialize the CUnit test registry */
@@ -24,8 +24,7 @@ int main() {
 	/* add the tests to the suite */
 	/* NOTE - ORDER IS IMPORTANT - MUST TEST fread() AFTER fprintf() */
 	if ((NULL == CU_add_test(pSuite, "test of coordinates", test_coordinates))
-	    || (NULL == CU_add_test(pSuite, "test of nsearch", test_nsearch))
-		) {
+			|| (NULL == CU_add_test(pSuite, "test of nsearch", test_nsearch))) {
 		CU_cleanup_registry();
 		return CU_get_error();
 	}
